@@ -452,7 +452,7 @@ def classify_log_type(connection, session):
 def do_classify(connection, session, work_dir, options):
 	rows = []
 	counter = LogCounter(N_COUNT)
-	log.info("Classifying images")
+	log.debug("Classifying images")
 	for name, in classify_session_iterable(connection, session):
 		file_path = os.path.join(work_dir, name)
 		row = classification_algorithm2(name, file_path, options)
@@ -518,7 +518,7 @@ def do_stats(connection, session, work_dir, options):
 	rows = []
 	counter = LogCounter(N_COUNT)
 	CameraImage.ExiftoolFixed = False
-	log.info("Computing image statistics")
+	log.debug("Computing image statistics")
 	for name, hsh in stats_session_iterable(connection, session):
 		file_path = os.path.join(work_dir, name)
 		image = CameraImage(file_path, camera_cache)
@@ -553,7 +553,7 @@ def do_stats(connection, session, work_dir, options):
 # ---------------
 
 def do_metadata(connection, session, options):
-	log.info("Updating Global Metadata")
+	log.debug("Updating Global Metadata")
 	row = vars(options)
 	row['state']   = METADATA_UPDATED
 	row['session'] = session
@@ -664,10 +664,16 @@ def master_dark_db_update_all(connection, session):
 			session, 
 			MIN(roi), 
 			COUNT(*), 
-			AVG(aver_signal_R1 - bias), 
-			AVG(aver_signal_G2 - bias), 
-			AVG(aver_signal_G3 - bias), 
-			AVG(aver_signal_B4 - bias),
+			-- This should be the proper treatment
+			-- AVG(aver_signal_R1 - bias),
+			-- AVG(aver_signal_G2 - bias),
+			-- AVG(aver_signal_G3 - bias),
+			-- AVG(aver_signal_B4 - bias),
+			-- Current treatment: Do not substract BIAS from raw signal to perform master dark
+			AVG(aver_signal_R1),
+			AVG(aver_signal_G2),
+			AVG(aver_signal_G3),
+			AVG(aver_signal_B4),
 			SUM(vari_signal_R1)/COUNT(*),
 			SUM(vari_signal_G2)/COUNT(*),
 			SUM(vari_signal_G3)/COUNT(*),
@@ -706,10 +712,16 @@ def master_dark_db_update_session(connection, session):
 			session, 
 			MIN(roi), 
 			COUNT(*), 
-			AVG(aver_signal_R1 - bias), 
-			AVG(aver_signal_G2 - bias), 
-			AVG(aver_signal_G3 - bias), 
-			AVG(aver_signal_B4 - bias),
+			-- This should be the proper treatment
+			-- AVG(aver_signal_R1 - bias),
+			-- AVG(aver_signal_G2 - bias),
+			-- AVG(aver_signal_G3 - bias),
+			-- AVG(aver_signal_B4 - bias),
+			-- Current treatment: Do not substract BIAS from raw signal to perform master dark
+			AVG(aver_signal_R1),
+			AVG(aver_signal_G2),
+			AVG(aver_signal_G3),
+			AVG(aver_signal_B4),
 			SUM(vari_signal_R1)/COUNT(*),
 			SUM(vari_signal_G2)/COUNT(*),
 			SUM(vari_signal_G3)/COUNT(*),
@@ -761,7 +773,7 @@ def do_apply_dark(connection, session, options):
 # -----------
 
 
-VIEW_HEADERS = [
+EXPORT_HEADERS = [
 			'tstamp'         ,
 			'name'           ,
 			'model'          ,
@@ -777,6 +789,14 @@ VIEW_HEADERS = [
 			'std_signal_G3'  ,
 			'aver_signal_B4' ,
 			'std_signal_B4'  ,
+			'aver_dark_R1'   ,
+			'std_dark_R1'    ,
+			'aver_dark_G2'   ,
+			'std_dark_G2'    ,
+			'aver_dark_G3'   ,
+			'std_dark_G3'    ,
+			'aver_dark_B4'   ,
+			'std_dark_B4'    ,
 			'bias'           ,
 		]
 
@@ -806,7 +826,15 @@ def export_session_iterable(connection, session):
 				aver_signal_G3, 
 				vari_signal_G3, -- Array index 17
 				aver_signal_B4, 
-				vari_signal_B4,  -- Array index 19
+				vari_signal_B4, -- Array index 19
+				aver_dark_R1, 
+				vari_dark_R1,   -- Array index 21
+				aver_dark_G2, 
+				vari_dark_G2,   -- Array index 23
+				aver_dark_G3, 
+				vari_dark_G3,   -- Array index 25
+				aver_dark_B4, 
+				vari_dark_B4,   -- Array index 27
 				bias
 		FROM image_t
 		WHERE state >= :state
@@ -843,6 +871,14 @@ def export_all_iterable(connection):
 				vari_signal_G3, -- Array index 17
 				aver_signal_B4, 
 				vari_signal_B4, -- Array index 19
+				aver_dark_R1, 
+				vari_dark_R1,   -- Array index 21
+				aver_dark_G2, 
+				vari_dark_G2,   -- Array index 23
+				aver_dark_G3, 
+				vari_dark_G3,   -- Array index 25
+				aver_dark_B4, 
+				vari_dark_B4,   -- Array index 27
 				bias
 		FROM image_t
 		WHERE state >= :state
@@ -855,12 +891,16 @@ def export_all_iterable(connection):
 def var2std(item):
 	'''From Variance to StdDev in several columns'''
 	index, value = item
-	value = round(math.sqrt(value),1) if index in [13, 15, 17, 19] else value
+	# Calculate stddev from variance and round to one decimal place
+	if  index in  [13, 15, 17, 19, 21, 23, 25, 27]:
+		value = round(math.sqrt(value),1)
 	# Round the aver_signal channels too
-	value = round(value,1) if index in [12, 14, 16, 18] else value
+	elif index in [12, 14, 16, 18, 20, 22, 24, 26]:
+		value = round(value, 1)
 	return value
 
 
+
 def get_file_path(connection, session, work_dir, options):
 	# This is for automatic reductions mainly
 	key, ext  = os.path.splitext(options.config)
@@ -880,7 +920,7 @@ def get_file_path(connection, session, work_dir, options):
 def do_export_work_dir(connection, session, work_dir, options):
 	'''Export a working directory of image redictions to a single file'''
 	fieldnames = ["session","observer","organization","location","type"]
-	fieldnames.extend(VIEW_HEADERS)
+	fieldnames.extend(EXPORT_HEADERS)
 	if session_processed(connection, session):
 		# Write a session CSV file
 		session_csv_file = get_file_path(connection, session, work_dir, options)
@@ -898,7 +938,7 @@ def do_export_work_dir(connection, session, work_dir, options):
 def do_export_all(connection,  options):
 	'''Exports all the database to a single file'''
 	fieldnames = ["session","observer","organization","location","type"]
-	fieldnames.extend(VIEW_HEADERS)
+	fieldnames.extend(EXPORT_HEADERS)
 	with myopen(options.csv_file, 'w') as csvfile:
 		writer = csv.writer(csvfile, delimiter=';')
 		writer.writerow(fieldnames)
@@ -1383,8 +1423,13 @@ def do_image_reduce(connection, options):
 	do_apply_dark(connection, session, options)
 
 	# Step 6
-	if register_deleted or stats_computed or metadata_updated:
-		do_export_work_dir(connection, session, options.work_dir, options)
+	if register_deleted or stats_computed or metadata_updated or options.force_csv:
+		try:
+			do_export_work_dir(connection, session, options.work_dir, options)
+		except IOError as e:
+			log.error(e)
+			work_dir_cleanup(connection)
+			raise
 	else:
 		log.info("NO CSV file generation is needed for session %d", session)
 
